==> isc-py-common-0.0.254.tar.gz: isc-py-common-0.0.254/isc_common/common/__init__.py <==
import os
from typing import Text
from uuid import UUID


def getOrElse(default, value):
    if value:
        return value
    else:
        return default


black = "black"
blue = "blue"
closed = "closed"
create = "create"
deleted = "deleted"
doing = "doing"
execution="execution"
formirovanie="formirovanie"
green = "green"
handmade = "handmade"
in_production="in_production"
launched = "launched"
made = "made"
new = "new"
new_man = "new_man"
not_relevant = "not_relevant"
orange = "orange"
otkryt = "otkryt"
otmenen = "otmenen"
red = "red"
restarted = "restarted"
route_made="route_made"
started = "started"
stoped = "stoped"
transferred = "transferred"
update = "update"
value_odd = "value_odd"
zakryt = "zakryt"

name_new="Новый"
name_new_s="Новый (с)"
name_new_h="Новый (р)"
name_started="Запущен"
name_restarted="Запущен (повторно)"
name_transferred="Назначенный"
name_stoped="Остановлен"
name_doing="Выполнен"
name_closed="Закрыт"
name_formirovanie="Формирование"
name_handmade="Системный (ручное формирование)"


def blinkString(text, blink=True, color="black", bold=False) -> Text:
    if blink:
        res = f'<div class="blink"><strong><font color="{color}"</font>{text}</strong></div>'
    else:
        res = f'<div><strong><font color="{color}"</font>{text}</strong></div>'

    if bold == True:
        return f'<b>{res}</b>'
    else:
        return res


def uuid5():
    return UUID(bytes=os.urandom(16), version=4)

def uuid4():
    return str(UUID(bytes=os.urandom(16), version=4)).upper().replace('-', '_')

==> isc-py-common-0.0.257.tar.gz: isc-py-common-0.0.257/isc_common/common/__init__.py <==
import os
from typing import Text
from uuid import UUID


def getOrElse(default, value):
    if value:
        return value
    else:
        return default


black = "black"
blue = "blue"
closed = "closed"
create = "create"
deleted = "deleted"
doing = "doing"
execution="execution"
formirovanie="formirovanie"
green = "green"
light_green = "#99CC00"
gray = "#808080"
handmade = "handmade"
in_production="in_production"
launched = "launched"
made = "made"
new = "new"
new_man = "new_man"
not_relevant = "not_relevant"
orange = "orange"
otkryt = "otkryt"
otmenen = "otmenen"
red = "red"
restarted = "restarted"
started_another = "started_another"
route_made="route_made"
sht = "шт"
started = "started"
stoped = "stoped"
transferred = "transferred"
unknown = "unknown"
update = "update"
value_odd = "value_odd"
zakryt = "zakryt"

name_closed="Закрыт"
name_doing="Выполнен"
name_formirovanie="Формирование"
name_handmade="Системный (ручное формирование)"
name_new="Новый"
name_new_h="Новый (р)"
name_new_s="Новый (с)"
name_restarted="Запущен (повторно)"
name_started="Запущен"
name_started_another="Запущен (раннее)"
name_stoped="Остановлен"
name_transferred="Назначенный"
name_unknown="Неопределеный"


def blinkString(text, blink=True, color="black", bold=False) -> Text:
    if blink:
        res = f'<div class="blink"><strong><font color="{color}"</font>{text}</strong></div>'
    else:
        res = f'<div><strong><font color="{color}"</font>{text}</strong></div>'

    if bold == True:
        return f'<b>{res}</b>'
    else:
        return res


def uuid5():
    return UUID(bytes=os.urandom(16), version=4)

def uuid4():
    return str(UUID(bytes=os.urandom(16), version=4)).upper().replace('-', '_')
